import vega from 'vega';
import vegaLite from 'vega-lite';
//import vegaEmbeded from 'vega-embeded';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: view => { view.tooltip(new Handler().call); }
});

//vega_embeded(renderer = c("canvas", "svg"));

//config is used by viz
const run = async () => {
  const marks = viz
    .data(await getData())
    .width(window.innerWidth)
    .height(window.innerHeight)
    .autosize({ type: 'fit', contains: 'padding' })
//    .width({ step:20 })
//    .height(180)
    .config(config);  
  
    document.body.appendChild(await marks.render());
};
//run();

// Datasets
// FIP codes
// https://www2.census.gov/geo/docs/reference/codes/files/national_county.txt
// https://en.wikipedia.org/wiki/Federal_Information_Processing_Standard_state_code
//
// Unemployment rates
// https://www.bls.gov/lau/#tables

// https://bl.ocks.org/mbostock/4060606
var svg = d3.select("svg"),
    width = +svg.attr("width")/2,
    height = +svg.attr("height")/2;

var path = d3.geoPath();

//debugger;
//const unemployment = d3.map();

var x = d3.scaleLinear()
    .domain([1, 10])
    .rangeRound([400, 660]);

var color = d3.scaleThreshold()
//    .domain(d3.range(0.01, 0.14))
    .domain(d3.range(2, 10))
    .range(d3.schemeGreens[9]);
//    .range(d3.schemeBlues[9]);

// Create element for legend
var g = svg.append("g")
    .attr("class", "key")
    .attr("transform", "translate(180,35)");

// Legend color scale
g.selectAll("rect")
    .data(color.range().map(function(d) {
      d = color.invertExtent(d);
      if (d[0] == null) d[0] = x.domain()[0];
      if (d[1] == null) d[1] = x.domain()[1];
      return d;
    }))
    .enter().append("rect")
    .attr("height", 8)
    .attr("x", function(d) { return x(d[0]); })
    .attr("width", function(d) { return x(d[1]) - x(d[0]); })
    .attr("fill", function(d) { return color(d[0]); });

// Legend title - "ILI %"
g.append("text")
    .attr("class", "caption")
    .attr("x", x.range()[0])
    .attr("y", -6)
    .attr("fill", "#000")
    .attr("text-anchor", "start")
    .attr("font-weight", "bold")
    .text("ILI %");

// Legend markings - 2%, 3%, etc.
g.call(d3.axisBottom(x)
    .tickSize(13)
    .tickFormat(function(x, i) { return i ? x : x + "%"; })
    .tickValues(color.domain()))
    .select(".domain")
    .remove();

d3.queue()
    .defer(d3.json, "https://d3js.org/us-10m.v1.json")
 // .defer(d3.tsv, "unemployment.tsv", function(d) { unemployment.set(d.id, +d.rate); })
    .defer(d3.tsv, "unemployment-states.tsv", function(d) { unemployment.set(d.id, +d.rate); })
//    .defer(d3.tsv, "stateILI.tsv", function(d) { unemployment.set(d.id, +d.rate); })
    .await(ready);

function ready(error, us) {
  if (error) throw error;

  console.log(us, unemployment);
  svg.append("g")
     .attr("class", "states")
     .selectAll("path")
  // .data(topojson.feature(us, us.objects.counties).features)
     .data(topojson.feature(us, us.objects.states).features)
     .enter().append("path")
     .attr("fill", function(d) {
        // console.log(d);
        return color(d.rate = unemployment.get(d.id));
      })
     .attr("d", path)
     .append("title") // Tooltip
     .text(function(d) { return d.rate + "%"; });

  svg.append("path")
     .datum(topojson.mesh(us, us.objects.states, function(a, b) { return a !== b; }))
     .attr("class", "states-borders")
     .attr("d", path);
}